@@ -194,7 +194,7 @@ predict.FuzzyExponentialNaiveBayes <- function(object,
     # -------------------------
     Infpos <- which(R_M_obs==Inf)
     R_M_obs[Infpos] <- .Machine$integer.max;
-    R_M_obs <- matrix(unlist(R_M_obs),ncol = cols)
+    R_M_obs <- matrix(unlist(R_M_obs),ncol = length(unique(M)))
     R_M_obs <- R_M_obs/rowSums(R_M_obs,na.rm = T)
     # ----------
     colnames(R_M_obs) <- unique(M)
